<?php

$locale["%s Kb (%s bytes)"] =
   "%s Х(%s Х)";
$locale["%s bytes"] =
   "%s Х";
$locale["%s bytes written"] =
   "%s  ХȽ񤭹ߤޤ";
$locale["%s is empty."] =
   "%s Ǥ";
$locale["%s: Bad action"] =
   "%s: ʤǤ";
$locale["%s: Can't open dba database"] =
   "%s: dba ǡ١򥪡ץޤ";
$locale["%s: file not found"] =
   "%s: ե뤬Ĥޤ";
$locale["%s: not defined"] =
   "%s: ̤Ǥ";
$locale["'%s': Bad page name"] =
   "'%s': ڡ̾ޤ";
$locale["(diff)"] =
   "(ʬ)";
$locale["<no matches>"] =
   "<פޤ>";
$locale["<none>"] =
   "<ʤ>";
$locale["<system language>"] =
   "<ƥ>";
$locale["<system theme>"] =
   "<ƥơ>";
$locale["Action page"] =
   "ڡ";
$locale["Add a Comment"] =
   "ɲ";
$locale["Adjust"] =
   "Ĵ";
$locale["Admin"] =
   "";
$locale["AllPages"] =
   "ڡ";
$locale["AllUsers"] =
   "桼";
$locale["Allowed protocols"] =
   "Ĥץȥ";
$locale["Appearance"] =
   "";
$locale["Application name"] =
   "ץꥱ̾";
$locale["Application size: %d Kb"] =
   "ץꥱ󥵥: %d Х";
$locale["Arguments"] =
   "";
$locale["Auth Level"] =
   "ǧڥ٥";
$locale["Auth Method"] =
   "ǧˡ";
$locale["Available plugins"] =
   "ͭʥץ饰";
$locale["Bad Version"] =
   "Сޤ";
$locale["Blog page"] =
   "Blogڡ";
$locale["Browsing pages"] =
   "ڡǤ";
$locale["Cache statistics"] =
   "å";
$locale["Calendar"] =
   "";
$locale["Cannot create directory '%s'"] =
   "ǥ쥯ȥ '%s' ޤ";
$locale["Change Password"] =
   "ѥѹ";
$locale["Change country"] =
   "̾ѹ";
$locale["Comment"] =
   "";
$locale["Complete."] =
   "λޤ";
$locale["Contents"] =
   "ƥ";
$locale["Create: %s"] =
   ": %s";
$locale["Creating pages"] =
   "ڡƤޤ";
$locale["Current Language"] =
   "ߤθ";
$locale["Current language: '%s'"] =
   "ߤθ: %s";
$locale["Current theme: '%s'"] =
   "ߤΥơ: %s";
$locale["Date Format"] =
   "ǡեޥå";
$locale["DebugInfo"] =
   "ǥХ";
$locale["Default theme: '%s'"] =
   "ǥեȥơ: %s";
$locale["Describe %s here."] =
   "%s򵭽Ҥޤ";
$locale["Description"] =
   "";
$locale["Dialog"] =
   "";
$locale["Diff"] =
   "ʬ";
$locale["Diff: %s"] =
   "ʬ: %s";
$locale["Diffing pages"] =
   "ڡκʬϤƤޤ";
$locale["Dump Pages as XHTML"] =
   "XHTMLǽ";
$locale["Dumping html pages"] =
   "HTMLڡϤƤޤ";
$locale["Dumping serial pages"] =
   "ꥢ饤ڡϤƤޤ";
$locale["E-Mail"] =
   "᡼";
$locale["Edit"] =
   "Խ";
$locale["Edit %s"] =
   "%s Խ";
$locale["Edit Area Size"] =
   "ԽꥢΥ";
$locale["Edit Old Revision"] =
   "ŤӥԽ";
$locale["Edit aborted."] =
   "ԽǤޤ";
$locale["Edit metadata for %s"] =
   "%s METAǡԽ";
$locale["Edit: %s"] =
   "Խ: %s";
$locale["EditMetaData"] =
   "METAǡԽ";
$locale["Editing pages"] =
   "ڡԽƤޤ";
$locale["Email not yet verified."] =
   "᡼륢ɥ쥹ǧޤǤ";
$locale["Email verified."] =
   "᡼륢ɥ쥹ǧޤ";
$locale["Empty pagename!"] =
   "ڡ̤̾Ǥ!";
$locale["Enter your UserId to sign in"] =
   "桼IDϤƥ󥤥󤷤Ƥ";
$locale["Fatal PhpWiki Error"] =
   "̿ŪPhpWikiΥ顼Ǥ";
$locale["FindPage"] =
   "ڡ";
$locale["First"] =
   "ǽ";
$locale["FullTextSearch"] =
   "ʸ";
$locale["H"] =
   "⤵";
$locale["Height"] =
   "⤵";
$locale["History of changes."] =
   "ѹ";
$locale["Hit statistics"] =
   "ҥå";
$locale["Hits"] =
   "ҥå";
$locale["Hits:"] =
   "ҥåȿ:";
$locale["HomePage"] =
   "ۡڡ";
$locale["Included from %s"] =
   "%s ɹޤޤ";
$locale["Index"] =
   "ǥå";
$locale["Inline images"] =
   "饤";
$locale["InterWiki Address"] =
   "InterWikiɥ쥹";
$locale["InterWikiSearch"] =
   "InterWiki";
$locale["Invalid password or userid."] =
   "桼IDѥɤ̵Ǥ";
$locale["Language"] =
   "";
$locale["Last"] =
   "Ǹ";
$locale["Last Author"] =
   "ǽԽ";
$locale["Last Modified"] =
   "ǽ";
$locale["Last Summary"] =
   "ǽ";
$locale["List PageHistory for %s"] =
   "%s Υڡ";
$locale["Load File"] =
   "եɹ";
$locale["Loading '%s'"] =
   "'%s' ɹǤ";
$locale["Loading files"] =
   "եɹǤ";
$locale["Lock Page"] =
   "ڡå";
$locale["Locked"] =
   "åޤ";
$locale["Locking pages"] =
   "ڡåǤ";
$locale["Login"] =
   "";
$locale["MIME file %s"] =
   "MIMEե %s";
$locale["Markup"] =
   "ޡå";
$locale["Markup cache purged!"] =
   "ޡåץå˴ޤ!";
$locale["Markup:"] =
   "ޡå:";
$locale["Name"] =
   "̾";
$locale["New comment."] =
   "";
$locale["New password"] =
   "ѥ";
$locale["Next"] =
   "";
$locale["Next Month"] =
   "η";
$locale["No changes found"] =
   "ѹĤޤǤ";
$locale["No changes."] =
   "ѹޤǤ";
$locale["No revisions found"] =
   "ӥ󤬸Ĥޤ";
$locale["None"] =
   "ʤ";
$locale["Note:"] =
   "Ρ:";
$locale["Okay"] =
   "ä";
$locale["OldStyleTable"] =
   "쥹Υơ֥";
$locale["PHP syntax highlighting"] =
   "PHPʸϥ饤";
$locale["Page Locked"] =
   "ڡåޤ";
$locale["Page Name"] =
   "ڡ̾";
$locale["Page Type:"] =
   "ڡμ<:";
$locale["Page Version:"] =
   "ڡС:";
$locale["Page now locked."] =
   "ڡϥåǤ";
$locale["Page now unlocked."] =
   "ڡϥåǤ";
$locale["Page statistics"] =
   "ڡ";
$locale["PageGroup"] =
   "ڡ롼";
$locale["PageHistory"] =
   "ڡ";
$locale["PageHistory for %s"] =
   "%s Υڡ";
$locale["PageInfo"] =
   "ڡ";
$locale["Password:"] =
   "ѥ:";
$locale["Personal language:"] =
   "Ŀ͸";
$locale["Personal theme:"] =
   "Ŀͥơ";
$locale["PhotoAlbum"] =
   "եȥХ";
$locale["PhpHighlight"] =
   "PHPϥ饤";
$locale["Please continue editing.  (You'll find your %s at the bottom of the page.)"] =
   "Խ³Ʋ (%s Υڡβ⸫Ƥ)";
$locale["Plugin"] =
   "ץ饰";
$locale["Plugin %s disabled."] =
   "ץ饰 %s ̵ˤʤäƤޤ";
$locale["Plugin %s failed."] =
   "ץ饰 %s Ԥޤ";
$locale["PluginManager"] =
   "ץ饰";
$locale["Plugins"] =
   "ץ饰";
$locale["PrevNext"] =
   "";
$locale["Preview"] =
   "ץӥ塼";
$locale["Preview only!  Changes not saved."] =
   "ץӥ塼ƤǤ! ޤ¸ϤƤޤ";
$locale["Previous"] =
   "";
$locale["Previous Author"] =
   "Խ";
$locale["Previous Month"] =
   "η";
$locale["Previous Revision"] =
   "Υӥ";
$locale["Printer"] =
   "ץ󥿡";
$locale["Purge Markup Cache"] =
   "ޡåץå˴";
$locale["RandomPage"] =
   "ڡ";
$locale["Raw HTML"] =
   "HTML";
$locale["RecentChanges"] =
   "ѹ";
$locale["Redirect"] =
   "ž";
$locale["References"] =
   "Ȱ";
$locale["Remove Page"] =
   "ڡ";
$locale["Remove selected pages"] =
   "ڡƺ";
$locale["Removing pages"] =
   "ڡǤ";
$locale["Return to %s"] =
   "%s ";
$locale["Revision Not Found"] =
   "ӥ󤬸Ĥޤ";
$locale["Save"] =
   "¸";
$locale["Score"] =
   "";
$locale["Search"] =
   "";
$locale["See %s"] =
   "%s 򻲾";
$locale["See: %s"] =
   ": %s";
$locale["Select: "] =
   ":";
$locale["Serialized file %s"] =
   "ꥢ饤ե %s";
$locale["Sidebar"] =
   "饤ɥС";
$locale["Sign In"] =
   "󥤥";
$locale["Sign Out"] =
   "󥵥";
$locale["SiteMap"] =
   "ȥޥå";
$locale["Size:"] =
   ":";
$locale["Sort by %s"] =
   "%sǥȤޤ";
$locale["Sound Score"] =
   "ɥ";
$locale["Status:"] =
   ":";
$locale["Submit"] =
   "";
$locale["Submit country"] =
   "̾";
$locale["Submit location"] =
   "ѹ";
$locale["Subpage"] =
   "֥ڡ";
$locale["Summary"] =
   "";
$locale["Supported languages"] =
   "ݡȸ";
$locale["Supported themes"] =
   "ݡȥơް";
$locale["Synopsis"] =
   "";
$locale["SystemInfo"] =
   "ƥ";
$locale["Theme"] =
   "ơ";
$locale["Time Zone"] =
   "ॾ";
$locale["Title Search"] =
   "ȥ븡";
$locale["TitleSearch"] =
   "ȥ븡";
$locale["Today"] =
   "";
$locale["Top & bottom toolbars"] =
   "ȲΥġС";
$locale["Total %d plugins: "] =
   " %d ץ饰";
$locale["Total of %d themes: "] =
   "ơ޿: %d";
$locale["Type it again"] =
   "⤦";
$locale["Unlock Page"] =
   "ڡå";
$locale["Unlocking pages"] =
   "ڡΥåǤ";
$locale["Update Preferences"] =
   "򹹿ޤ";
$locale["Upload"] =
   "åץ";
$locale["Uploading %s"] =
   "%s 򥢥åץǤ";
$locale["Use old markup"] =
   "Ťޡåפ";
$locale["User page"] =
   "桼ڡ";
$locale["User statistics"] =
   "桼";
$locale["UserId"] =
   "桼ID";
$locale["UserId:"] =
   "桼ID:";
$locale["UserPreferences"] =
   "桼";
$locale["Using directory '%s'"] =
   "ǥ쥯ȥ '%s' ѤƤޤ";
$locale["Version"] =
   "С";
$locale["Version %d"] =
   "С %d";
$locale["Version %s"] =
   "С %s";
$locale["View Source"] =
   "򸫤";
$locale["View Source: %s"] =
   "򸫤: %s";
$locale["View the current version"] =
   "ߤΥСɽ";
$locale["W"] =
   "";
$locale["Warning: You are editing an old revision."] =
   "ٹ: ʤϸŤӥԽƤޤ";
$locale["Width"] =
   "";
$locale["Wiki Name"] =
   "Wiki̾";
$locale["WikiForm: %s: unknown action"] =
   "WikiForm: '%s' ̤ΤǤ";
$locale["Your E-Mail:"] =
   "ʤΥ᡼륢ɥ쥹:";
$locale["cached pagedata:"] =
   "ڡǡ򥭥å:";
$locale["cached versiondata:"] =
   "Сǡ򥭥å:";
$locale["compare revisions"] =
   "ӥ";
$locale["current version"] =
   "ߤΥС";
$locale["diff"] =
   "ʬ";
$locale["edit area"] =
   "Խꥢ";
$locale["from %s"] =
   "%s ";
$locale["home page"] =
   "ۡڡ";
$locale["locked"] =
   "åޤ";
$locale["max: %d"] =
   ": %d";
$locale["no cache used"] =
   "åȤޤ";
$locale["plain file %s"] =
   "ץ쥤ե %s";
$locale["previous revision"] =
   "Υӥ";
$locale["saved as %s"] =
   "%s ¸ޤ";
$locale["today"] =
   "";
$locale["too long"] =
   "Ĺޤ";
$locale["use this plugin"] =
   "Υץ饰Ȥ";
$locale["version %d"] =
   "С %d";
$locale["version %s"] =
   "С %s";
$locale["yesterday"] =
   "";

?>
